powered by
Set or modify x axis labels.
bb_categories(bb, categories)
A `billboard` `htmlwidget` object.
A character vector to set names on a category axis.
# Simple line with month names as x labels billboarder() %>% bb_linechart(data = round(rnorm(12))) %>% bb_categories(categories = month.name)
Run the code above in your browser using DataLab