Skip to contents

Helper for creating a gauge

Usage

bb_gaugechart(
  bb,
  value,
  name = "Value",
  color = NULL,
  steps = c(30, 60, 90, 100),
  steps_color = c("#FF0000", "#F97600", "#F6C600", "#60B044"),
  ...
)

Arguments

bb

A `billboard` `htmlwidget` object.

value

A single numeric value or a vector for stacked gauge.

name

Name for the value, appear in tooltip, same length as `value`.

color

Color for the gauge, if provided, `steps` and `steps_color` are ignored.

steps

Upper bound for changing colors

steps_color

Colors corresponding to steps

...

Arguments for slot gauge.

Value

A `billboard` `htmlwidget` object.

Note

This function can be used with [billboarderProxy()] in Shiny applications.

Examples

billboarder() %>%
  bb_gaugechart(value = 50)
# With some options billboarder() %>% bb_gaugechart( value = 160, steps_color = rev(c("#FF0000", "#F97600", "#F6C600", "#60B044")) ) %>% bb_gauge( label = list(format = suffix("km/h")), min = 10, max = 200, width = 20 )